==> pyifdm-1.1.0.tar.gz: pyifdm-1.1.0/pyifdm/methods/if_marcos.py <==
# Copyright (c) 2023 Jakub Więckowski

from .marcos.ifs import ifs
from ..helpers import rank

from .validator import Validator


class ifMARCOS():
    def __init__(self):
        """
        Create Intuitionistic Fuzzy MARCOS method object

        """

        self.__descending = True

    def __call__(self, matrix, weights, types):
        """
        Calculates the alternatives preferences

        Parameters
        ----------
            matrix : ndarray
                Decision matrix / alternatives data.
                Alternatives are in rows and Criteria are in columns.

            weights : ndarray
                Vector of criteria weights in a crisp or Intuitionistic Fuzzy form

            types : ndarray
                Types of criteria, 1 profit, -1 cost

        Returns
        ----------
            ndarray:
                Preference calculated for alternatives. Greater values are placed higher in ranking
        """
        # validate data
        Validator.ifs_validation(matrix, weights, types, mixed_types=True, crisp_weights=True)

        self.preferences = ifs(matrix, weights, types).astype(float)
        return self.preferences

    def rank(self):
        """
            Calculates the alternatives ranking based on the obtained preferences

            Returns
            ----------
                ndarray:
                    Ranking of alternatives
        """
        try:
            return rank(self.preferences, self.__descending)
        except AttributeError:
            raise AttributeError('Cannot calculate ranking before assessment')
        except:
            raise ValueError('Error occurred in ranking calculation')

==> pyifdm-1.1.1.tar.gz: pyifdm-1.1.1/pyifdm/methods/if_marcos.py <==
# Copyright (c) 2023 Jakub Więckowski

from .marcos.ifs import ifs
from ..helpers import rank

from .validator import Validator


class ifMARCOS():
    def __init__(self):
        """
        Create Intuitionistic Fuzzy MARCOS method object

        """

        self.__descending = True

    def __call__(self, matrix, weights, types):
        """
        Calculates the alternatives preferences

        Parameters
        ----------
            matrix : ndarray
                Decision matrix / alternatives data.
                Alternatives are in rows and Criteria are in columns.

            weights : ndarray
                Vector of criteria weights in a crisp or Intuitionistic Fuzzy form

            types : ndarray
                Types of criteria, 1 profit, -1 cost

        Returns
        ----------
            ndarray:
                Preference calculated for alternatives. Greater values are placed higher in ranking
        """
        # validate data
        Validator.ifs_validation(matrix, weights, types, mixed_types=True)

        self.preferences = ifs(matrix, weights, types).astype(float)
        return self.preferences

    def rank(self):
        """
            Calculates the alternatives ranking based on the obtained preferences

            Returns
            ----------
                ndarray:
                    Ranking of alternatives
        """
        try:
            return rank(self.preferences, self.__descending)
        except AttributeError:
            raise AttributeError('Cannot calculate ranking before assessment')
        except:
            raise ValueError('Error occurred in ranking calculation')
